package de.hawhamburg.reachability.registry.json;

import de.hawhamburg.lifecycle.data.JsonLPObject;
import de.hawhamburg.reachability.reasoner.enumeration.ReasonerDimension;
import de.hawhamburg.reachability.registry.enumeration.RegistryAgentType;
import de.hawhamburg.reachability.registry.enumeration.RegistryMessageType;

/**
 * JSON message to register or unregister an agent be the systems registry service.<br><br>
 * 
 * This class represents the JSON message with which an agent is able to register or unregister itself by the systems
 * registry service via the ActiveMQ.
 * 
 * @author  {@value de.hawhamburg.reachability.ProjectInfo#REACHABILITY_AGENT_AUTHOR} 
 * @version {@value de.hawhamburg.reachability.ProjectInfo#REACHABILITY_AGENT_VERSION}
 */
public class JsonRARegistryMessage extends JsonLPObject {
    
    /**
     * The type of registration as {@link RegistryMessageType}.
     */
    public RegistryMessageType MessageType;
    
    
    /**
     * The type of agent as {@link RegistryAgentType} which sends this message.
     */
    public RegistryAgentType AgentType;
    
    /**
     * The name of the agent sending this message as {@link String}.
     */
    public String Name;
    
    /**
     * The context dimension which this agent may support (only for {@link RegistryAgentType#SENSOR} as 
     * {@link ReasonerDimension}.
     */
    public ReasonerDimension Dimension;
    
    /**
     * A remark.
     */
    public String Remark;
    
    /**
     * Public default constructor to create instances of this class.
     */
    public JsonRARegistryMessage() { }
    
}
